<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+272"/>
        <source>None</source>
        <translation>无</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translation>英寸</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translation>英尺</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translation>英里</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translation>毫米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translation>厘米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translation>米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translation>千米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translation>微英寸</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translation>密耳</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translation>码</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translation>埃</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translation>纳米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translation>微米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translation>分米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translation>十米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translation>百米</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translation>百万公里</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translation>天文单位</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translation>光年</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translation>秒差距</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+340"/>
        <source>By Layer</source>
        <translation>按图层</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>按块</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translation>红色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Green</source>
        <translation>绿色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Blue</source>
        <translation>蓝色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cyan</source>
        <translation>青色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Magenta</source>
        <translation>洋红色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Yellow</source>
        <translation>黄色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Orange</source>
        <translation>橙色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>暗红色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>深绿色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>藏青色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>深青绿</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>深洋红</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>暗黄</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translation>黑色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gray</source>
        <translation>灰色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translation>浅灰色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translation>白色</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Others...</source>
        <translation>其它...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+48"/>
        <source>Current Layer ID</source>
        <translation>当前图层 ID</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>绘图单元</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>线性比例</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>尺寸字体</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/REntity.cpp" line="+95"/>
        <source>Block</source>
        <translation>块</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+102"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+80"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>位置</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+75"/>
        <source>Pixel Unit</source>
        <translation>像素单位</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+83"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+75"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>原点</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>布局</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Owned by Reference</source>
        <translation>由参照拥有</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>External reference</source>
        <translation>外部参照</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-7"/>
        <source>Referenced Block</source>
        <translation>引用块</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>External Reference</source>
        <translation>外部参照</translation>
    </message>
    <message>
        <location line="+4"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translation>比例</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translation>角度</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>列</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>行</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>列间距</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>行间距</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation>属性</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="-1"/>
        <location filename="../src/core/RObject.cpp" line="+70"/>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layer</source>
        <translation>图层</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+104"/>
        <source>Linetype</source>
        <translation>线型</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>线型比例</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translation>线宽</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translation>颜色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>显示颜色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translation>描画顺序</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Parent Id</source>
        <translation>父级 ID</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>边界</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>左</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>底部</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>右</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>上部</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+162"/>
        <source>Custom</source>
        <translation>自定义</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>处理</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>受保护</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Selected</source>
        <translation>选择的</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Object Invisible</source>
        <translation>对象不可见</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Working Set</source>
        <translation>工作集</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+2"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>宽度</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
    <message>
        <location line="+0"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>高度</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>简单</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>文本位置</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>文字</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>普通文本</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>字体名称</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>文本高度</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Width</source>
        <translation>文本宽度</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>文字角度</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>X 比例</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>加粗</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>斜体</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>行距</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>对齐</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>水平</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>垂直</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Backward</source>
        <translation>置底</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Upside Down</source>
        <translation>倒置</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>旋转</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation>开</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>视图中心点</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>视图目标点</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation>顶层</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Frozen Layers</source>
        <translation>冻结图层</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer ID</source>
        <translation>图层 ID</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-8"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayerState.cpp" line="+46"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>隐藏</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation>关</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>冻结</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>锁定</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>分解</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>可打印</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>可捕捉</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation>冻结</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation>跳格</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>最小界限</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>最大界限</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation>插入基点</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>最小扩展</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>最大扩展</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+920"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>检测到循环（递归）块引用：</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>块名称：</translation>
    </message>
    <message>
        <location filename="../src/core/RDimStyle.cpp" line="+71"/>
        <source>Style</source>
        <translation>样式</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Overall scale</source>
        <translation>全局比例</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear measurement factor</source>
        <translation>线性测量比例</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text height</source>
        <translation>文字高度</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line gap</source>
        <translation>尺寸线间隙</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow size</source>
        <translation>箭头大小</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension line increment</source>
        <translation>尺寸线增量</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line extension</source>
        <translation>尺寸界线延伸</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Extension line offset</source>
        <translation>尺寸界线偏移</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text position vertical</source>
        <translation>文本垂直位置</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text horizontal</source>
        <translation>文本水平对齐</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tick size</source>
        <translation>标记大小</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linear format</source>
        <translation>线性格式</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal places</source>
        <translation>小数位数</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Decimal separator</source>
        <translation>小数分隔符</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zero suppression</source>
        <translation>零抑制</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular format</source>
        <translation>角度格式</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular decimal places</source>
        <translation>角度小数位数</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angular zero suppression</source>
        <translation>角度零抑制</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Architectur tick</source>
        <translation>建筑标记</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text color</source>
        <translation>文字颜色</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block</source>
        <translation>箭头块</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 1</source>
        <translation>箭头块 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arrow block 2</source>
        <translation>箭头块 2</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+203"/>
        <source>Requires selection</source>
        <translation>需要选择</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+51"/>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>描述</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>米制</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>图案</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+912"/>
        <source>By Layer</source>
        <translation>按图层</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>按块</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>连续线</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>边界</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>居中</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>点划线</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>虚线</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>分割线</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>点</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>隐藏</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>阴影</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>ISO 虚线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISO 虚线间隔</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>ISO 长点划线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>ISO 双点划线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>ISO 三角点划线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>ISO 点</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>ISO 长短划线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>ISO 双短划线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>ISO 点划线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>ISO 双划点线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISO 双点划线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISO 双虚线双点划线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISO 虚线三点划线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISO 双虚线三点划线</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>热水供应</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>热水</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>煤气管道</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>拍打</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>锯齿</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>轨迹</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>围墙线1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>围墙线2</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point 1</source>
        <translation>点 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point 2</source>
        <translation>点 2</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plant</source>
        <translation>植物</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Water</source>
        <translation>水管</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage</source>
        <translation>排水系统</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>反向排水</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Communication</source>
        <translation>通信线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Electric</source>
        <translation>电线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Low Voltage</source>
        <translation>低压线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>High Voltage</source>
        <translation>高压线</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Overhead Power</source>
        <translation>架空电力线</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Foul</source>
        <translation>污水管</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Foul Rising</source>
        <translation>污水上升管</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+37"/>
        <source>By Layer</source>
        <translation>按图层</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>按块</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translation>默认值</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translation>0.00mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translation>0.05mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translation>0.09mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translation>0.13mm(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translation>0.15mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translation>0.18mm(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translation>0.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translation>0.25(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translation>0.30mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translation>0.35mm(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translation>0.40mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translation>0.50mm(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translation>0.53mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translation>0.60mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translation>0.70mm(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translation>0.80mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translation>0.90mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translation>1.00mm(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translation>1.06mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translation>1.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translation>1.40mm(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translation>1.58mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translation>2.00mm(ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translation>2.11mm</translation>
    </message>
</context>
</TS>
